<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;


class AuthController extends Controller
{
    //Menampilkan login
    public function index()
    {
        return view('auth.login');
    }

    //Memproses login
    public function login(Request $request)
    {
        // Validasi input
        $request->validate([
            'email' => 'required|email',
            'password' => 'required',
        ]);

        // Cek kredensial
        if (Auth::attempt($request->only('email', 'password'))) {
            // Redirect ke halaman dashboard setelah login
            return redirect()->route('author.dashboard-author'); // Ganti dengan rute dashboard Anda
        }

        // Jika gagal, kembali ke halaman login dengan pesan error
        return back()->withErrors([
            'email' => 'The provided credentials do not match our records.',
        ]);
    }
    public function adminDashboard()
    {
        return view("admin.dashboard-admin");
    }

    public function authorDashboard()
    {
        return view("author.dashboard-author");
    }


    //Menampilkan halaman register

    public function showRegister()
    {
        return view('auth.register');
    }


    public function register(Request $request)
    {
        // Validasi
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:6|confirmed', // menggunakan `confirmed` untuk konfirmasi password
        ], [
            'name.required' => 'Nama wajib diisi',
            'email.required' => 'Email wajib diisi',
            'email.email' => 'Format email tidak valid',
            'email.unique' => 'Email sudah digunakan',
            'password.required' => 'Password wajib diisi',
            'password.min' => 'Password harus memiliki minimal 6 karakter',
            'password.confirmed' => 'Konfirmasi password tidak cocok',
        ]);

        if ($validator->fails()) {
            return redirect()->back()->withErrors($validator->messages()->all()[0]);
        }

        // Simpan data pengguna
        $user = new User();
        $user->name = $request->name;
        $user->email = $request->email;
        $user->password = Hash::make($request->password);

        try {
            // dd($request->all());     
            $user->save();
            return redirect()->route('login')->with('success', 'Data Berhasil Disimpan!');
        } catch (\Throwable $th) {
            return back()->with('error', 'Terjadi kesalahan: ' . $th->getMessage());
        }
    }

    public function showLoginForm()
    {
        return view('auth.login'); // Pastikan view ini ada
    }

    // Fungsi logout
    public function logout()
    {
        Auth::logout();
        return redirect()->route('login');
    }
}
