<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class UserController extends Controller
{
    public function showProfile()
    {
        $user = Auth::user();
        return view('user.profile.index', compact('user'));
    }

    public function updateProfile(Request $request)
    {
        $user = Auth::user();

        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users,email,' . $user->id,
        ]);

        $user->name = $request->name;
        $user->email = $request->email;
        $user->save();

        return back()->with('success', 'Profil berhasil diperbarui!');
    }

    public function showInputData()
    {
        return view('user.input-data.index');
    }

    public function processInputData(Request $request)
    {
        // Validasi input
        $validatedData = $request->validate([
            'jenis_tanaman' => 'required|string',
            'kebutuhan_nutrisi' => 'required|string',
        ]);

        // Redirect ke halaman rekomendasi sambil bawa data input
        return redirect()->route('user.rekomendasi.index')->with('inputData', $validatedData);
    }

    public function showRekomendasi()
    {
        // Ambil hasil penilaian SAW dari database
        $rekomendasi = DB::table('hasil_penilaian')
                        ->orderByDesc('nilai_akhir') // nilai tertinggi
                        ->first(); // Ambil satu pupuk terbaik

        // Jika rekomendasi ditemukan, ambil data alternatif
        if ($rekomendasi) {
            $alternatif = DB::table('alternatives')->find($rekomendasi->alternatif_id);
            return view('user.rekomendasi.index', compact('rekomendasi', 'alternatif'));
        }

        return view('user.rekomendasi.index', compact('rekomendasi'));
    }
}
