{{-- resources/views/admin/penilaian/index.blade.php --}}
@extends('layout.app')

@section('content')
<div class="container-fluid px-4">
    <h1 class="mt-4">Penilaian SAW</h1>
    <ol class="breadcrumb mb-4">
        <li class="breadcrumb-item"><a href="{{ route('admin.dashboard-admin') }}">Dashboard</a></li>
        <li class="breadcrumb-item active">Penilaian SAW</li>
    </ol>

    @if(session('success'))
    <div class="alert alert-success">
        {{ session('success') }}
    </div>
    @endif

    {{-- Form Penilaian Baru --}}
    <div class="card mt-4">
        <div class="card-header">
            <strong>📝 Form Penilaian</strong>
        </div>
        <div class="card-body">
            <form action="{{ route('penilaian.store') }}" method="POST">
                @csrf

                <div class="mb-3">
                    <label for="alternatif_id" class="form-label">Pilih Alternatif</label>
                    <select name="alternatif_id" id="alternatif_id" class="form-select" required>
                        <option value="">Pilih Alternatif…</option>
                        @foreach ($alternatifs as $alternatif)
                            <option value="{{ $alternatif->id }}">{{ $alternatif->name }}</option>
                        @endforeach
                    </select>
                </div>

                <div class="mb-3">
                    <label for="n" class="form-label">Kandungan Nitrogen (N)</label>
                    <input type="number" name="n" id="n" class="form-control" step="0.01" required>
                </div>

                <div class="mb-3">
                    <label for="p" class="form-label">Kandungan Fosfor (F)</label>
                    <input type="number" name="p" id="p" class="form-control" step="0.01" required>
                </div>

                <div class="mb-3">
                    <label for="k" class="form-label">Kandungan Kalium (K)</label>
                    <input type="number" name="k" id="k" class="form-control" step="0.01" required>
                </div>

                <div class="mb-3">
                    <label for="harga" class="form-label">Harga</label>
                    <input type="number" name="harga" id="harga" class="form-control" step="0.01" required>
                </div>

                <button type="submit" class="btn btn-primary">Simpan Penilaian</button>
            </form>
        </div>
    </div>

    {{-- Matriks Keputusan --}}
    @if(isset($penilaians) && $penilaians->count() > 0)
    <div class="card mt-4">
        <div class="card-header">
            <i class="fas fa-table me-1"></i>
            Matriks Keputusan
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Alternatif</th>
                            @foreach($kriterias ?? [] as $kriteria)
                            <th>{{ $kriteria->Kriteria }}</th>
                            @endforeach
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($alternatifs ?? [] as $alternatif)
                        <tr>
                            <td>{{ $alternatif->name }}</td>
                            @foreach($kriterias ?? [] as $kriteria)
                            <td>
                                @php
                                $nilai = $penilaians->where('alternatif_id', $alternatif->id)
                                                      ->where('kriteria_id', $kriteria->id)
                                                  ->first();
                                @endphp
                                {{ $nilai ? number_format($nilai->nilai, 2) : '-' }}
                            </td>
                            @endforeach
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    {{-- Matriks Normalisasi --}}
    <div class="card mb-4">
        <div class="card-header">
            <i class="fas fa-table me-1"></i>
            Matriks Normalisasi
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Alternatif</th>
                            @foreach($kriterias ?? [] as $kriteria)
                            <th>{{ $kriteria->Kriteria }}</th>
                            @endforeach
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($alternatifs ?? [] as $alternatif)
                        <tr>
                            <td>{{ $alternatif->name }}</td>
                            @foreach($kriterias ?? [] as $kriteria)
                            <td>
                                {{ isset($normalisasi[$alternatif->id][$kriteria->id]) 
                                    ? number_format($normalisasi[$alternatif->id][$kriteria->id], 4) 
                                    : '-' }}
                            </td>
                            @endforeach
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    {{-- Ranking --}}
    <div class="card mb-4">
        <div class="card-header">
            <i class="fas fa-chart-bar me-1"></i>
            Hasil Perangkingan
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Ranking</th>
                            <th>Alternatif</th>
                            <th>Nilai Akhir</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php $rank = 1; @endphp
                        @foreach($ranking ?? [] as $alternatif_id => $nilai)
                        <tr>
                            <td>{{ $rank++ }}</td>
                            <td>{{ $alternatifs->find($alternatif_id)->name }}</td>
                            <td>{{ number_format($nilai, 4) }}</td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    @endif

    {{-- Tombol Hapus Semua --}}
    <div class="mb-3">
        <form action="{{ route('penilaian.deleteAll') }}" method="POST" style="display: inline;">
            @csrf
            @method('DELETE')
            <button type="submit" class="btn btn-danger" onclick="return confirm('Apakah Anda yakin ingin menghapus semua penilaian?')">Hapus Semua Penilaian</button>
        </form>
    </div>
</div>
@endsection 
